--[[
************************************************************************
Project				: Broker_AllStats
Author				: zhinjio
Project Revision	: r2
Project Date		: 20081212001833

File				: Broker_AllStats.lua
Commit Author		: zhinjio
Commit Revision		: 2
Commit Date			: 20081212001833
************************************************************************
Description	:
	Main addon file. 
TODO		:
************************************************************************
(see bottom of file for changelog)
************************************************************************
--]]

local MODNAME = "AllStats"
local FULLNAME = "Broker_AllStats"
local Extractor = LibStub( "AceAddon-3.0" ):NewAddon( MODNAME, "AceEvent-3.0" )
local L = LibStub:GetLibrary( "AceLocale-3.0" ):GetLocale( MODNAME )
local AceConfig 		= LibStub("AceConfig-3.0")
local AceConfigReg 		= LibStub("AceConfigRegistry-3.0")
local AceConfigDialog 	= LibStub("AceConfigDialog-3.0")

_G[ MODNAME ] = AllStats
local addon = AllStats

local addonversion = "r2"
local addonauthor = "zhinjio"
local builddate = "20081212001833"

local modularOptions = {}
local tooltip
local LTT = LibStub:GetLibrary( "LibQTip-1.0" )

-- addon globals
-- addon.someValue = 0
addon.me = ""

local db

function addon.Print( msg )
	local _, fh = DEFAULT_CHAT_FRAME:GetFont()
	fh = math.ceil( fh )
	local icon = "\124TInterface\\Addons\\" .. FULLNAME .. "\\icon:" .. fh .. "\124t"
	if ( msg ~= nil ) then
	   if( DEFAULT_CHAT_FRAME ) then
	      DEFAULT_CHAT_FRAME:AddMessage( icon .. " " .. MODNAME .. " : " .. msg, 0.6, 1.0, 1.0 )
	   end
	end
end

function addon.Debug( msg )
	if ( msg ~= nil ) then
		if ( db.options.display.debug ) then
			addon.Print( "DEBUG: " .. msg )
		end
	end
end

-- coloring agents
--local function Orange ( text )
--	return "|cffdea51c" .. text .. "|r"
--end

local function HideTooltip()
	tooltip:SetScript( "OnLeave", nil )
	tooltip:Hide()
end

local function drawTooltip()
	tooltip:Hide()
	tooltip:Clear()

	-- tooltip display code here...

	tooltip:AddLine(" ")
--	tooltip:AddLine( L["Left-Click to cycle through maps"] )
	tooltip:AddLine( L["Right-click for Configuration"] )
end

-- LDB stuff
local LDB = LibStub( "LibDataBroker-1.1" )
local launcher = LDB:NewDataObject( MODNAME, {
	type = "data source",
	text = " ",
	label = FULLNAME,
	icon = "Interface\\Addons\\" .. FULLNAME .. "\\icon",
	OnClick = function( clickedframe, button )
				if button == "RightButton" then
					addon:ShowConfig()
				else
					drawTooltip()
					tooltip:SmartAnchorTo( clickedframe )
					tooltip:Show()
				end
	end,
	OnEnter = function ( self )
		drawTooltip()
		tooltip:EnableMouse()
		tooltip:SmartAnchorTo( self )
		tooltip:Show()
	end,
	OnLeave = function ( self )
		if MouseIsOver( tooltip ) then
			tooltip:SetScript( 'OnLeave', HideTooltip )
		else
			HideTooltip()
		end
	end,
} )

function addon.upgradeDB()
	local olddb = addon.db.factionrealm[addon.me]
	--[[
	if ( olddb.options.display.dbVersion == "1.0" ) then
		-- original version
		olddb.options.display.debug = false
		olddb.options.display.dbVersion = "1.1"
		addon.Print( string.format( L["Database upgraded to %s"], "1.1" ) )
	end
	]]--
end

-- options stuff
local displayOptions = nil
local function giveDisplay()
	if (not displayOptions) then
		displayOptions = {
			order = 2,
			type = "group",
			name = L["Display Options"],
			desc = L["DISPLAY_OPTIONS_DESC"],
			args = {
				header1 = {
					order	= 21,
					type	= "header",
					name	= L["Display Options"],
				},
				desc = {
					order	= 22,
					type	= "description",
					name	= L["DISPLAY_OPTIONS_DESC"],
				},
				sound = {
					order	= 23,
					type	= "toggle",
					name	= L["Enable DEBUG"],
					desc	= L["DISPLAY_DEBUG_DESC"],
					get		= function() return db.options.display.debug end,
					set		= function() db.options.display.debug = not db.options.display.debug end,
				},
				tooltipscale = {
					order	= 24,
					type	= "range",
					name	= L["Tooltip Scale"],
					desc	= L["TOOLTIP_SCALE_DESC"],
					min		= .7,
					max		= 1.3,
					step	= .05,
					bigStep = .05,
					get		= function() return db.options.display.tipscale end,
					set		= function( info, v ) 
								db.options.display.tipscale = v
								tooltip:SetScale( v )
							  end,
				},
			},
		}
	end
	return displayOptions
end

local options = nil
local function fullOptions()
	if (not options) then
		options = {
			type = "group",
			name = MODNAME,
			args = {
				general = {
					order	= 1,
					type	= "group",
					name	= L["General Information"],
					desc	= L["GENERAL_INFO_DESC"],
					args	= {
						header1 = {
							order	= 11,
							type	= "header",
							name	= L["General Information"],
						},
						desc = {
							order	= 12,
							type	= "description",
							name	= L["GENERAL_INFO_DESC"],
						},
						author = {
							order	= 13,
							type	= "description",
							name	= L["Author : "] .. addonauthor .. "\n",
						},
						version = {
							order	= 14,
							type	= "description",
							name	= L["Version : "] .. addonversion .. "\n",
						},
						builddate = {
							order	= 15,
							type	= "description",
							name	= L["Build Date : "] .. builddate .. "\n",
						},
						dbversion = {
							order	= 15,
							type	= "description",
							name	= L["Database Version : "] .. db.options.display.dbVersion .. "\n",
						},
						translators = {
							order	= 16,
							type	= "description",
							name	= string.format( L["Helpful Translators (thank you) : %s"], " \n" )
						},
					},
				},
			},
		}
	end
	
	for k,v in pairs(modularOptions) do
		options.args[k] = (type(v) == "function") and v() or v
	end

	return options
end

function addon:SetupOptions()
	AceConfigReg:RegisterOptionsTable(MODNAME, fullOptions)
	self.optionsFrame = AceConfigDialog:AddToBlizOptions(MODNAME, nil, nil, "general")

	-- Fill up our modular options...
	self:RegisterModuleOptions("Display", giveDisplay(), L["Display Options"])
end

function addon:RegisterModuleOptions(name, optionsTable, displayName)
	modularOptions[name] = optionsTable
	self.optionsFrame[name] = AceConfigDialog:AddToBlizOptions(MODNAME, displayName, MODNAME, name)
end

function addon:ShowConfig()
	-- Open the profiles tab before, so the menu expands
	InterfaceOptionsFrame_OpenToCategory( self.optionsFrame["Display"] )
end


function addon:OnInitialize()
	-- Do Frame Creation stuff here
	-- addon:CreateFrames()
end

function addon:OnEnable()
    -- Called when the addon is loaded
	addon.me = UnitName( "player" )

	self.db = LibStub( "AceDB-3.0" ):New( MODNAME .. "_DB", nil, "Default" )
	-- do we have any data yet; for this toon? If not, init its table
	if not ( self.db.factionrealm[addon.me] ) then
		self.db.factionrealm[addon.me] = {
		-- Your saved variables stuff here
			options = {
				display = {
					debug = false,
					tipscale = 1,
					dbVersion = "1.0",
				},
			},
		}
	else
		-- check if we need to upgrade the db
		addon.upgradeDB()
	end
	db = self.db.factionrealm[addon.me]

	-- tooltip setup and scaling
	tooltip = LTT:Acquire( MODNAME.."TT", 3, "LEFT", "CENTER", "RIGHT" ) -- or GameTooltip
	tooltip:SetScale( db.options.display.tipscale )

	addon:SetupOptions()
	-- Event listeners
    -- addon:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED")
end

--[[
************************************************************************
CHANGELOG:

11/20/08 : 
	Initial version
************************************************************************
]]--